require 'puppetx/puppetlabs/pe_console/console_http'

Puppet::Reports.register_report(:console) do
  desc <<-DESC
    Send reports to the console via HTTPS. This report processor submits reports as
    POST requests to the address in the `reporturl` setting. The body of each POST
    request is the YAML dump of a Puppet::Transaction::Report object, and the
    Content-Type is set as `application/x-yaml`.
  DESC

  # Because report processors run on the report instance itself, any instance
  # variables we need to have (like console config) need to live separate from
  # the report instance. So we use a class instance of a class whose entire
  # purpose is to ferry that data around for us. This also allows us to avoid
  # reloading the config every time we process a report.
  class ConsoleReportUploader
    include Puppetx::Puppetlabs::PEConsole::ConsoleHTTP

    def initialize
      load_config
    end

    def upload(report)
      path = config.report_path
      body = report.to_yaml

      begin
        response = do_request do |connection, headers|
          headers["Content-Type"] = "application/x-yaml"
          connection.post(path, body, headers)
        end
      rescue Puppet::Error => e
        Puppet.err "Unable to submit report: #{e}"
      end
    end
  end

  def self.report_uploader
    @report_uploader ||= ConsoleReportUploader.new
  end

  def process
    Puppet::Reports::Console.report_uploader.upload(self)
  end
end
